Name:          pivot
Version:       2.0.4
Release:       1%{?dist}
Summary:       Platform for building installable Internet applications (IIAs)
License:       ASL 2.0
URL:           https://pivot.apache.org/
Source0:       http://www.apache.org/dist/pivot/source/apache-%{name}-%{version}-src.tar.gz

BuildRequires: maven-local
BuildRequires: mvn(com.kitfox:kitfox-svg-salamander)
BuildRequires: mvn(javax.servlet:javax.servlet-api)
BuildRequires: mvn(junit:junit)
%if %{?fedora} > 23
BuildRequires: icedtea-web >= 1.6.1-5
#BuildRequires: mvn(sun.applet:icedtea-web-plugin)
%else
BuildRequires: mvn(net.sourceforge.htmlunit:htmlunit)
%endif
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)

BuildArch:     noarch

%description
Apache Pivot is an open-source platform for building
installable Internet applications (IIAs). It combines
the enhanced productivity and usability features of
a modern user interface toolkit with the robustness of
the Java platform. 

%package charts
Summary:       Apache Pivot Charts

%description charts
Classes for adding interactive charting
capabilities to Pivot applications.

%package parent
Summary:       Apache Pivot Parent POM

%description parent
This package provides Apache Pivot Parent POM.

%package web
Summary:       Apache Pivot Web Library

%description web
Classes to facilitate communication with remote data services.

%package web-server
Summary:       Apache Pivot Web Server Library

%description web-server
Classes to facilitate implementation of server-side data services.

%package wtk
Summary:       Apache Pivot WTK Library

%description wtk
Classes for user interface development, including windows,
dialogs, buttons, lists, text input, layout, drag and drop,
XML markup, etc.

%package wtk-terra
Summary:       Apache Pivot WTK Terra Theme Library

%description wtk-terra
The default WTK theme provider for Pivot,
responsible for the look & feel of the
user interface components.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n apache-%{name}-%{version}-src
find -name '*.class' -print -delete
find -name '*.jar' -print -delete

# Swith to xmvn, default use maven-ant-plugin 
sed -i "s|@VERSION@|%{version}|" $(find . -name "pom.xml")

%pom_xpath_inject pom:modules '<module>web-server</module>'

# Set encoding
%pom_xpath_inject pom:project '
<properties>
  <project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
  <project.reporting.outputEncoding>UTF-8</project.reporting.outputEncoding>
</properties>'

for p in charts \
 core \
 web \
 web-server \
 wtk \
 wtk-terra
do
# Set Re-Sources location
%pom_xpath_inject pom:project '
  <build>
    <sourceDirectory>src</sourceDirectory>
    <testSourceDirectory>test</testSourceDirectory>
    <resources>
      <resource>
        <directory>src</directory>
        <excludes>
          <exclude>**/*.java</exclude>
          <exclude>**/package.html</exclude>
        </excludes>
      </resource>
      <resource>
        <directory>../</directory>
        <targetPath>META-INF</targetPath>
        <includes>
          <include>LICENSE</include>
          <include>NOTICE</include>
          <include>README</include>
        </includes>
      </resource>
    </resources>
    <testResources>
      <testResource>
        <directory>test</directory>
      </testResource>
    </testResources>
  </build>' ${p}
# Add test deps
  %pom_add_dep junit:junit:4.12:test ${p}
# Add OSGi support
  %pom_xpath_set "pom:project/pom:packaging" bundle ${p}
  %pom_add_plugin org.apache.felix:maven-bundle-plugin:2.5.4 ${p} "
  <extensions>true</extensions>
  <configuration>
    <instructions>
      <Bundle-SymbolicName>\${project.groupId}.${p}</Bundle-SymbolicName>
      <Bundle-Name>\${project.artifactId}</Bundle-Name>
      <Bundle-Version>\${project.version}</Bundle-Version>
      <Implementation-Title>\${project.name}</Implementation-Title>
      <Implementation-Vendor>The Apache Software Foundation</Implementation-Vendor>
      <Implementation-Vendor-Id>org.apache</Implementation-Vendor-Id>
      <Implementation-Version>\${project.version}</Implementation-Version>
      <Sealed>true</Sealed>
    </instructions>
  </configuration>
  <executions>
    <execution>
      <id>bundle-manifest</id>
      <phase>process-classes</phase>
      <goals>
        <goal>manifest</goal>
      </goals>
    </execution>
  </executions>"
done

# package javax.servlet does not exist
%pom_add_dep javax.servlet:javax.servlet-api:3.1.0 web-server
# package com.kitfox.svg does not exist
%pom_add_dep com.kitfox:kitfox-svg-salamander:1.0.8 wtk
# package netscape.javascript does not exist
%if %{?fedora} > 23
%pom_add_dep sun.applet:icedtea-web-plugin:1.6.1 wtk
%else
%pom_add_dep net.sourceforge.htmlunit:htmlunit:2.17 wtk
%endif

%build

%mvn_build -s

%install
%mvn_install

%files -f .mfiles-pivot-core
%doc README RELEASE-NOTES
%license LICENSE NOTICE

%files charts -f .mfiles-pivot-charts
%files parent -f .mfiles-pivot
%files web -f .mfiles-pivot-web
%files web-server -f .mfiles-pivot-web-server
%files wtk -f .mfiles-pivot-wtk
%files wtk-terra -f .mfiles-pivot-wtk-terra

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Sat Dec 12 2015 gil cattaneo <puntogil@libero.it> 2.0.4-1
- initial rpm

